==> vizro-0.1.20.tar.gz: vizro-0.1.20/docs/index.md <==
# Vizro

Vizro is a toolkit for creating modular data visualization applications.

<div class="grid cards" markdown>

-   :fontawesome-solid-forward-fast:{ .lg .middle } __New to Vizro?__

    ---

    [:octicons-arrow-right-24: Quickstart tutorial](pages/tutorials/first-dashboard.md) </br>
    [:octicons-arrow-right-24: Install Vizro](pages/user-guides/install.md)




-   :fontawesome-solid-keyboard:{ .lg .middle } __Vizro features__

    ---

    [:octicons-arrow-right-24: Fundamentals](pages/user-guides/dashboard.md)</br>
    [:octicons-arrow-right-24: Components overview](pages/user-guides/components.md)</br>
    [:octicons-arrow-right-24: Filters, parameters and selectors](pages/user-guides/filters.md)</br>
    [:octicons-arrow-right-24: Visual formatting](pages/user-guides/layouts.md)



-   :fontawesome-solid-microscope:{ .lg .middle } __Hands-on code__

    ---

    [:octicons-arrow-right-24: Tutorials](pages/tutorials/explore-components.md) <br/>
    [:octicons-arrow-right-24: Examples](pages/examples/examples.md)



-   :material-scale-balance:{ .lg .middle } __FAQs__

    ---

    [:octicons-arrow-right-24: How is Vizro different to Streamlit?](pages/explanation/faq.md/#how-does-vizro-differ-from-dash-or-streamlit) <br/>
    [:octicons-arrow-right-24: Other FAQs](pages/explanation/faq.md) <br/>
    [:octicons-arrow-right-24: Where can I ask a question?](pages/explanation/contributing.md/#got-a-vizro-question) <br/>



-   :fontawesome-solid-hands-holding-circle:{ .lg .middle } __Get involved__

    ---

    [:octicons-arrow-right-24: Contribute code](pages/explanation/contributing.md) <br/>
    [:octicons-arrow-right-24: Contribute to our docs](pages/explanation/documentation-style-guide.md)

-   :fontawesome-solid-chart-column:{ .lg .middle } __Vizro-AI__

    ---

    [:octicons-arrow-right-24: Vizro-AI: Use natural language queries to build Plotly charts](https://vizro.readthedocs.io/projects/vizro-ai/)


</div>

==> vizro-0.1.24.tar.gz: vizro-0.1.24/docs/index.md <==
# Vizro

Vizro is a toolkit for creating modular data visualization applications.

<div class="grid cards" markdown>

-   :fontawesome-solid-forward-fast:{ .lg .middle } __New to Vizro?__

    ---

    [:octicons-arrow-right-24: Quickstart tutorial](pages/tutorials/first-dashboard.md) </br>
    [:octicons-arrow-right-24: Install Vizro](pages/user-guides/install.md)




-   :fontawesome-solid-keyboard:{ .lg .middle } __Vizro features__

    ---

    [:octicons-arrow-right-24: Fundamentals](pages/user-guides/dashboard.md)</br>
    [:octicons-arrow-right-24: Components overview](pages/user-guides/components.md)</br>
    [:octicons-arrow-right-24: Filters, parameters and selectors](pages/user-guides/filters.md)</br>
    [:octicons-arrow-right-24: Visual formatting](pages/user-guides/visual-formatting.md)



-   :fontawesome-solid-microscope:{ .lg .middle } __Hands-on code__

    ---

    [:octicons-arrow-right-24: Tutorials](pages/tutorials/explore-components.md) <br/>
    [:octicons-arrow-right-24: Examples](pages/examples/examples.md)



-   :material-scale-balance:{ .lg .middle } __FAQs__

    ---

    [:octicons-arrow-right-24: How is Vizro different to Streamlit?](pages/explanation/faq.md/#how-does-vizro-differ-from-dash-or-streamlit) <br/>
    [:octicons-arrow-right-24: Where can I ask a question about Vizo?](pages/explanation/faq.md/#i-still-have-a-question-where-can-i-ask-it) <br/>
    [:octicons-arrow-right-24: Other FAQs](pages/explanation/faq.md) <br/>



-   :fontawesome-solid-hands-holding-circle:{ .lg .middle } __Get involved__

    ---

    [:octicons-arrow-right-24: Contribute code](pages/explanation/contributing.md) <br/>
    [:octicons-arrow-right-24: Contribute to our docs](pages/explanation/documentation-style-guide.md)

-   :fontawesome-solid-chart-column:{ .lg .middle } __Vizro-AI__

    ---

    [:octicons-arrow-right-24: Vizro-AI: Use natural language queries to build Plotly charts](https://vizro.readthedocs.io/projects/vizro-ai/)


</div>
